[Libreoffice-commits] core.git: framework/qa officecfg/registry qadevOOo/tests sd/source svgio/source svtools/source vcl/source

Julien Nabet serval2412 at yahoo.fr
Thu Feb 26 14:03:44 PST 2015


 framework/qa/complex/XUserInputInterception/EventTest.java                   |    8 +++---
 framework/qa/complex/contextMenuInterceptor/CheckContextMenuInterceptor.java |    2 -
 framework/qa/complex/framework/recovery/RecoveryTest.java                    |    6 ++---
 officecfg/registry/schema/org/openoffice/Office/Draw.xcs                     |    2 -
 officecfg/registry/schema/org/openoffice/Office/Impress.xcs                  |    2 -
 qadevOOo/tests/java/ifc/awt/_XUserInputInterception.java                     |   12 +++++-----
 qadevOOo/tests/java/ifc/sheet/_XEnhancedMouseClickBroadcaster.java           |    2 -
 qadevOOo/tests/java/ifc/ui/_XContextMenuInterception.java                    |    2 -
 sd/source/ui/func/futext.cxx                                                 |    6 ++---
 svgio/source/svgreader/svgstyleattributes.cxx                                |    2 -
 svtools/source/control/tabbar.cxx                                            |    2 -
 vcl/source/filter/sgvtext.cxx                                                |    2 -
 12 files changed, 24 insertions(+), 24 deletions(-)

New commits:
commit ca7f62c8262662c8f58a3fa3b298623f25b55eaa
Author: Julien Nabet <serval2412 at yahoo.fr>
Date:   Thu Feb 26 23:02:35 2015 +0100

    Typos
    
    Change-Id: Ic03fb2ee6470eac6034be13908dd9ec92cf175b6

diff --git a/framework/qa/complex/contextMenuInterceptor/CheckContextMenuInterceptor.java b/framework/qa/complex/contextMenuInterceptor/CheckContextMenuInterceptor.java
index 532dc9d..916e570 100644
--- a/framework/qa/complex/contextMenuInterceptor/CheckContextMenuInterceptor.java
+++ b/framework/qa/complex/contextMenuInterceptor/CheckContextMenuInterceptor.java
@@ -298,7 +298,7 @@ public class CheckContextMenuInterceptor
         point = window.getLocationOnScreen();
         Rectangle rect = window.getBounds();
 
-        System.out.println("klick mouse button...");
+        System.out.println("click mouse button...");
         try
         {
             Robot rob = new Robot();
diff --git a/framework/qa/complex/framework/recovery/RecoveryTest.java b/framework/qa/complex/framework/recovery/RecoveryTest.java
index 6bf108c..6f16401 100644
--- a/framework/qa/complex/framework/recovery/RecoveryTest.java
+++ b/framework/qa/complex/framework/recovery/RecoveryTest.java
@@ -310,9 +310,9 @@ public class RecoveryTest extends ComplexTestCase {
       * office is started after a crash. It waits until the "next>>" button is enabled
       * and click it then to continue.
       * @param expectedDocumentCount the amount of documents which must be displayed in the recovery dialog
-      * @param recover If the documenst should be recoverd this variable must be true. If it is fasle
-      * the recovery process was stopped and the button cancel was klicked.
-      * @param cancel If the recovery is fifnished, this parameter desicdes to klick the "Next" button
+      * @param recover If the document should be recovered this variable must be true. If it is false
+      * the recovery process was stopped and the button cancel was clicked.
+      * @param cancel If the recovery is finished, this parameter decides to click the "Next" button
       * or the click cancel. If the value is true, the cancel button was clicked.
       */
     private void handleRecoveryDialogAtRestart(int expectedDocumentCount, boolean recover, boolean cancel){
diff --git a/officecfg/registry/schema/org/openoffice/Office/Draw.xcs b/officecfg/registry/schema/org/openoffice/Office/Draw.xcs
index b786be4..f92e9a1 100644
--- a/officecfg/registry/schema/org/openoffice/Office/Draw.xcs
+++ b/officecfg/registry/schema/org/openoffice/Office/Draw.xcs
@@ -421,7 +421,7 @@
       <group oor:name="DefaultObjectSize">
         <!-- OldPath: -->
         <!-- OldLocation: -->
-        <!-- UIHints: Default size for newly created objects when using CTRL-Return or CTRL-Klick -->
+        <!-- UIHints: Default size for newly created objects when using CTRL-Return or CTRL-Click -->
         <info>
           <desc>Defines the default size of newly created objects using CTRL-Return or CTRL-Click at a object creating Button</desc>
           <label>Default Object Size</label>
diff --git a/officecfg/registry/schema/org/openoffice/Office/Impress.xcs b/officecfg/registry/schema/org/openoffice/Office/Impress.xcs
index 3c89f9f..276476a 100644
--- a/officecfg/registry/schema/org/openoffice/Office/Impress.xcs
+++ b/officecfg/registry/schema/org/openoffice/Office/Impress.xcs
@@ -655,7 +655,7 @@
       <group oor:name="DefaultObjectSize">
         <!-- OldPath: -->
         <!-- OldLocation: -->
-        <!-- UIHints: Default size for newly created objects when using CTRL-Return or CTRL-Klick -->
+        <!-- UIHints: Default size for newly created objects when using CTRL-Return or CTRL-Click -->
         <info>
           <desc>Defines the default size of newly created objects using CTRL-Return or CTRL-Click at a object creating Button.</desc>
           <label>Default Object Size</label>
diff --git a/qadevOOo/tests/java/ifc/sheet/_XEnhancedMouseClickBroadcaster.java b/qadevOOo/tests/java/ifc/sheet/_XEnhancedMouseClickBroadcaster.java
index 55da8c1..1a6a583 100644
--- a/qadevOOo/tests/java/ifc/sheet/_XEnhancedMouseClickBroadcaster.java
+++ b/qadevOOo/tests/java/ifc/sheet/_XEnhancedMouseClickBroadcaster.java
@@ -88,7 +88,7 @@ public class _XEnhancedMouseClickBroadcaster extends MultiMethodTest {
         Point point = window.getLocationOnScreen();
         Rectangle rect = window.getBounds();
 
-        log.println("klick mouse button...");
+        log.println("click mouse button...");
         try {
             Robot rob = new Robot();
             int x = point.X + (rect.Width / 2)+50;
diff --git a/qadevOOo/tests/java/ifc/ui/_XContextMenuInterception.java b/qadevOOo/tests/java/ifc/ui/_XContextMenuInterception.java
index 243fdc0..3935c90 100644
--- a/qadevOOo/tests/java/ifc/ui/_XContextMenuInterception.java
+++ b/qadevOOo/tests/java/ifc/ui/_XContextMenuInterception.java
@@ -167,7 +167,7 @@ public class _XContextMenuInterception extends MultiMethodTest {
         point = window.getLocationOnScreen();
         Rectangle rect = window.getBounds();
 
-        log.println("klick mouse button...");
+        log.println("click mouse button...");
         try {
             Robot rob = new Robot();
             int x = point.X + (rect.Width / 2);
diff --git a/sd/source/ui/func/futext.cxx b/sd/source/ui/func/futext.cxx
index 5e9bf1e..0f46a8d 100644
--- a/sd/source/ui/func/futext.cxx
+++ b/sd/source/ui/func/futext.cxx
@@ -513,7 +513,7 @@ void FuText::ImpSetAttributesForNewTextObject(SdrTextObj* pTxtObj)
             aSet.Put(makeSdrTextAutoGrowWidthItem(true));
             aSet.Put(makeSdrTextAutoGrowHeightItem(false));
 
-            // Set defaults for vertical klick-n'drag text object, pool defaults are:
+            // Set defaults for vertical click-n'drag text object, pool defaults are:
             // SdrTextVertAdjustItem: SDRTEXTVERTADJUST_TOP
             // SdrTextHorzAdjustItem: SDRTEXTHORZADJUST_BLOCK
             // Analog to that:
@@ -796,10 +796,10 @@ bool FuText::MouseButtonUp(const MouseEvent& rMEvt)
                 {
                     // Here, all items which need to be different from pool default need to be set
                     // again on the newly created text object.
-                    // Since this is a simple klick text object, it is first created, then SetVertical()
+                    // Since this is a simple click text object, it is first created, then SetVertical()
                     // is used, then ImpSetAttributesForNewTextObject is called and then the object is
                     // deleted again since not the minimum drag distance was travelled. Then, a new
-                    // klick text object is created and thus all that stuff needs to be set again here.
+                    // click text object is created and thus all that stuff needs to be set again here.
 
                     // Before using the new object the vertical writing mode
                     // needs to be set. This is done here at the OutlinerParaObject
diff --git a/svgio/source/svgreader/svgstyleattributes.cxx b/svgio/source/svgreader/svgstyleattributes.cxx
index fa71c63..888c8d9 100644
--- a/svgio/source/svgreader/svgstyleattributes.cxx
+++ b/svgio/source/svgreader/svgstyleattributes.cxx
@@ -2272,7 +2272,7 @@ namespace svgio
             if(maFontSize.isSet())
             {
                 // #122524# Handle Unit_percent realtive to parent FontSize (see SVG1.1
-                // spec 10.10 Font selection properties \91font-size\92, lastline (klick 'normative
+                // spec 10.10 Font selection properties \91font-size\92, lastline (click 'normative
                 // definition of the property')
                 if(Unit_percent == maFontSize.getUnit())
                 {
diff --git a/svtools/source/control/tabbar.cxx b/svtools/source/control/tabbar.cxx
index 056ab91..a3d14ae 100644
--- a/svtools/source/control/tabbar.cxx
+++ b/svtools/source/control/tabbar.cxx
@@ -859,7 +859,7 @@ void TabBar::MouseMove( const MouseEvent& rMEvt )
 
 void TabBar::MouseButtonDown( const MouseEvent& rMEvt )
 {
-    // Only terminate EditModus and do not execute Klick
+    // Only terminate EditModus and do not execute click
     // if clicked inside our window,
     if ( IsInEditMode() )
     {
diff --git a/vcl/source/filter/sgvtext.cxx b/vcl/source/filter/sgvtext.cxx
index be511231..a069259 100644
--- a/vcl/source/filter/sgvtext.cxx
+++ b/vcl/source/filter/sgvtext.cxx
@@ -798,7 +798,7 @@ void FormatLine(UCHAR* TBuf, sal_uInt16& Index, ObjTextType& Atr0, ObjTextType&
     switch (Just) {
         case THJustLeft: break;                                // left
         case THJustCenter: {
-            BoxRest=BoxRest /2;                                // middel
+            BoxRest=BoxRest /2;                                // middle
             for (i=1;i<=nChars;i++) Line[i]=Line[i]+BoxRest;
         } break;
         case THJustRight: {                                    // right


More information about the Libreoffice-commits mailing list
diff --git a/framework/qa/complex/XUserInputInterception/EventTest.java b/framework/qa/complex/XUserInputInterception/EventTest.java
index f337495..86c0051 100644
--- a/framework/qa/complex/XUserInputInterception/EventTest.java
+++ b/framework/qa/complex/XUserInputInterception/EventTest.java
@@ -454,10 +454,10 @@ public class EventTest {
             }
         }
         /**
-         * This method cklicks into the middel of a document. It uses Accessibility
+         * This method clicks into the middle of a document. It uses Accessibility
          * to get the document and query for its position and its range to calculate
          * the middle. This values was used for <CODE>Robot</CODE> Class. This
          * Robot class is able to move the mouse and to cklick a mouse button
          * @see java.awt.Robot
         */
         private void clickIntoDoc(){
@@ -484,7 +484,7 @@ public class EventTest {
                     Robot rob = new Robot();
                     int x = point.X + (rect.Width / 2);
                     int y = point.Y + (rect.Height / 2);
-                    System.out.println("try to klick into the middle of the document");
+                    System.out.println("try to click into the middle of the document");
                     rob.mouseMove(x, y);
                     rob.mousePress(InputEvent.BUTTON1_MASK);
                     rob.mouseRelease(InputEvent.BUTTON1_MASK);
@@ -520,7 +520,7 @@ public class EventTest {
     */
     private interface EventTriggerType{
 
         /** klick the mouse into the scroll bar*/
         int MOUSE_KLICK_INTO_DOC = 1;
 
         /** write some text into a spread sheet*/
@@ -454,10 +454,10 @@ public class EventTest {
          * to get the document and query for its position and its range to calculate
          * the middle. This values was used for <CODE>Robot</CODE> Class. This
-         * Robot class is able to move the mouse and to cklick a mouse button
+         * Robot class is able to move the mouse and to click a mouse button
          * @see java.awt.Robot
         */
@@ -520,7 +520,7 @@ public class EventTest {
     private interface EventTriggerType{
 
-        /** klick the mouse into the scroll bar*/
+        /** click the mouse into the scroll bar*/
         int MOUSE_KLICK_INTO_DOC = 1;
 
diff --git a/qadevOOo/tests/java/ifc/awt/_XUserInputInterception.java b/qadevOOo/tests/java/ifc/awt/_XUserInputInterception.java
index 43bffcf..58ccffa 100644
--- a/qadevOOo/tests/java/ifc/awt/_XUserInputInterception.java
+++ b/qadevOOo/tests/java/ifc/awt/_XUserInputInterception.java
@@ -174,7 +174,7 @@ public class _XUserInputInterception extends MultiMethodTest {
     }
 
     /**
      * This test adds two different mouse klick listener to the object. <p>
      *
      * Has <b> OK </b> if no exception is thrown.
      */
@@ -194,7 +194,7 @@ public class _XUserInputInterception extends MultiMethodTest {
 
     /**
      *  The test requires <CODE>addMouseClickHandler()</CODE> which adds two key listener.
      * Then one of them will be removed. In a second thread a mouse klick event is released
      * by the <CODE>robot</CODE> class.<p>
      * Has <b> OK </b> status if only one of the listener are triggered. <p>
      * The following method tests are to be completed successfully before :
@@ -452,10 +452,10 @@ public class _XUserInputInterception extends MultiMethodTest {
             }
         }
         /**
-         * This method cklicks into the middel of a document. It uses Accessibility
+         * This method clicks into the middle of a document. It uses Accessibility
          * to get the document and query for its position and its range to calculate
          * the middle. This values was used for <CODE>Robot</CODE> Class. This
          * Robot class is able to move the mouse and to cklick a mouse button
          * @see java.awt.Robot
         */
         private void clickIntoDoc(){
@@ -483,7 +483,7 @@ public class _XUserInputInterception extends MultiMethodTest {
                     Robot rob = new Robot();
                     int x = point.X + (rect.Width / 2);
                     int y = point.Y + (rect.Height / 2);
-                    log.println("try to klick into the middle of the document");
+                    log.println("try to click into the middle of the document");
                     rob.mouseMove(x, y);
                     rob.mousePress(InputEvent.BUTTON1_MASK);
                     rob.mouseRelease(InputEvent.BUTTON1_MASK);
@@ -519,7 +519,7 @@ public class _XUserInputInterception extends MultiMethodTest {
     */
     private interface EventTriggerType{
 
         /** klick the mouse into the scroll bar*/
         int MOUSE_KLICK_INTO_DOC = 1;
 
         /** write some text into a spread sheet*/
@@ -174,7 +174,7 @@ public class _XUserInputInterception extends MultiMethodTest {
 
     /**
-     * This test adds two different mouse klick listener to the object. <p>
+     * This test adds two different mouse click listener to the object. <p>
      *
      * Has <b> OK </b> if no exception is thrown.
@@ -194,7 +194,7 @@ public class _XUserInputInterception extends MultiMethodTest {
     /**
      *  The test requires <CODE>addMouseClickHandler()</CODE> which adds two key listener.
-     * Then one of them will be removed. In a second thread a mouse klick event is released
+     * Then one of them will be removed. In a second thread a mouse click event is released
      * by the <CODE>robot</CODE> class.<p>
      * Has <b> OK </b> status if only one of the listener are triggered. <p>
@@ -452,10 +452,10 @@ public class _XUserInputInterception extends MultiMethodTest {
          * to get the document and query for its position and its range to calculate
          * the middle. This values was used for <CODE>Robot</CODE> Class. This
-         * Robot class is able to move the mouse and to cklick a mouse button
+         * Robot class is able to move the mouse and to click a mouse button
          * @see java.awt.Robot
         */
@@ -519,7 +519,7 @@ public class _XUserInputInterception extends MultiMethodTest {
     private interface EventTriggerType{
 
-        /** klick the mouse into the scroll bar*/
+        /** click the mouse into the scroll bar*/
         int MOUSE_KLICK_INTO_DOC = 1;
 